@@ -21,18 +21,26 @@ The AWS Access Key ID of the owner of the security group.
 
 The name of the security group.
 
+=item group_id (required)
+
+The id of the security group.
+
 =item group_description (required)
 
 The description of the security group.
 
 =item ip_permissions (optional)
 
-An array ref of Net::Amazon::EC2::IpPermission objects.
+An array ref of Net::Amazon::EC2::IpPermission objects for ingress.
 
+=item ip_permissions_egress (optional)
+
+An array ref of Net::Amazon::EC2::IpPermission objects for egress.
 =cut
 
 has 'owner_id'          => ( is => 'ro', isa => 'Str', required => 1 );
 has 'group_name'        => ( is => 'ro', isa => 'Str', required => 1 );
+has 'group_id'          => ( is => 'ro', isa => 'Str', required => 1 );
 has 'group_description' => ( is => 'ro', isa => 'Str', required => 1 );
 has 'ip_permissions'    => ( 
     is          => 'ro', 
@@ -40,6 +48,12 @@ has 'ip_permissions'    => (
     predicate   => 'has_ip_permissions',
     default		=> sub { [ ] },
 );
+has 'ip_permissions_egress' => ( 
+    is          => 'ro', 
+    isa         => 'Maybe[ArrayRef[Net::Amazon::EC2::IpPermission]]',
+    predicate   => 'has_ip_permissions_egress',
+    default		=> sub { [ ] },
+);
 
 __PACKAGE__->meta->make_immutable();
 
@@ -57,4 +71,4 @@ under the same terms as Perl itself.
 =cut
 
 no Moose;
-1;
\ No newline at end of file
+1;
